[patch] gcc/*.[ch]: Follow spelling conventions.

Kazu Hirata kazu@cs.umass.edu
Sat Nov 16 09:53:00 GMT 2002


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2002-11-16  Kazu Hirata  <kazu@cs.umass.edu>

	* hard-reg-set.h: Follow spelling conventions.
	* real.c: Likewise.
	* target.h: Likewise.

Index: hard-reg-set.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/hard-reg-set.h,v
retrieving revision 1.17
diff -u -r1.17 hard-reg-set.h
--- hard-reg-set.h	4 Nov 2002 16:57:01 -0000	1.17
+++ hard-reg-set.h	16 Nov 2002 17:46:33 -0000
@@ -488,7 +488,7 @@
 
 extern const char * reg_names[FIRST_PSEUDO_REGISTER];
 
-/* Given a hard REGN a FROM mode and a TO mode, return non-zero if
+/* Given a hard REGN a FROM mode and a TO mode, return nonzero if
    REGN cannot change modes between the specified modes.  */
 #define REG_CANNOT_CHANGE_MODE_P(REGN, FROM, TO)                          \
         (TEST_HARD_REG_BIT                                                \
Index: target.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/target.h,v
retrieving revision 1.41
diff -u -r1.41 target.h
--- target.h	22 Oct 2002 23:05:12 -0000	1.41
+++ target.h	16 Nov 2002 17:46:35 -0000
@@ -123,7 +123,7 @@
     /* Output the assembler code for a thunk function.  THUNK_DECL is the
        declaration for the thunk function itself, FUNCTION is the decl for
        the target function.  DELTA is an immediate constant offset to be
-       added to THIS.  If VCALL_OFFSET is non-zero, the word at
+       added to THIS.  If VCALL_OFFSET is nonzero, the word at
        *(*this + vcall_offset) should be added to THIS.  */
     void (* output_mi_thunk) PARAMS ((FILE *file, tree thunk_decl,
 				      HOST_WIDE_INT delta,



More information about the Gcc-patches mailing list
Index: real.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/real.c,v
retrieving revision 1.103
diff -u -r1.103 real.c
--- real.c	27 Oct 2002 14:47:54 -0000	1.103
+++ real.c	16 Nov 2002 17:46:35 -0000
@@ -410,7 +410,7 @@
   return 0;
 }
 
-/* Return true if A is non-zero.  */
+/* Return true if A is nonzero.  */
 
 static inline int 
 cmp_significand_0 (a)
@@ -1675,8 +1675,8 @@
   /* Round the result.  */
   if (digit == 5)
     {
-      /* Round to nearest.  If R is non-zero there are additional
-	 non-zero digits to be extracted.  */
+      /* Round to nearest.  If R is nonzero there are additional
+	 nonzero digits to be extracted.  */
       if (cmp_significand_0 (&r))
 	digit++;
       /* Round to even.  */